===========================
|makinage-logo| Maki Nage
===========================

.. |makinage-logo| image:: docs/asset/makinage_logo.png

The Reactive Machine Learning Framework

.. image:: https://badge.fury.io/py/makinage.svg
    :target: https://badge.fury.io/py/makinage

.. image:: https://github.com/maki-nage/makinage/workflows/Python%20package/badge.svg
    :target: https://github.com/maki-nage/makinage/actions?query=workflow%3A%22Python+package%22
    :alt: Github WorkFlows

.. image:: https://readthedocs.org/projects/maki-nage/badge/?version=latest
    :target: https://maki-nage.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Key Features
============


Getting started
===============

.. code:: console

    makinage --config myconfig.yaml
